@@ -20,7 +20,7 @@ y1 <- y123.dat[,1]
 M1 <- glm (y1 ~ x1)
 
 cases <- data.frame(x1 = seq(-2, 2, by=0.1))
-sim.results <- gelmansim(M1, newdata=cases, nsims=200, na.omit=TRUE)
+sim.results <- gelmansim(mod = M1, newdata = cases, n.sims=200, na.omit=TRUE)
 
 
 test_that("returned dataframe is correct size", {
@@ -45,7 +45,7 @@ M2 <- glm (y1 ~ x1 + group, data=dat)
 cases <- expand.grid(x1 = seq(-2, 2, by=0.1), 
                     group=seq(1, 14, by=2))
 
-sim.results <- gelmansim(M2, newdata=cases, nsims=200, na.omit=TRUE)
+sim.results <- gelmansim(M2, newdata=cases, n.sims=200, na.omit=TRUE)
 
 test_that("returned dataframe is correct size", {
   expect_that(dim(sim.results)[1], equals(nrow(cases)))
@@ -70,7 +70,7 @@ cases <- expand.grid(x1 = seq(-2, 2, by=0.1),
                      group=seq(1, 14, by=2))
 cases$group <- factor(cases$group)
 
-sim.results <- gelmansim(M3, newdata=cases, nsims=200, na.omit=TRUE)
+sim.results <- gelmansim(M3, newdata=cases, n.sims=200, na.omit=TRUE)
 
 test_that("returned dataframe is correct size", {
   expect_that(dim(sim.results)[1], equals(nrow(cases)))
@@ -86,3 +86,28 @@ test_that("values of simulations are sensible", {
   expect_that(all(!is.na(sim.results$yhatMax)), is_true())
 })
 
+context("Check multivariate LM case with factor")
+
+dat$group <- factor(dat$group)
+M4 <- lm(y1 ~ x1 + group, data=dat)
+
+cases <- expand.grid(x1 = seq(-2, 2, by=0.1), 
+                     group=seq(1, 14, by=2))
+cases$group <- factor(cases$group)
+
+sim.results <- gelmansim(M4, newdata=cases, n.sims=200, na.omit=TRUE)
+
+
+test_that("returned dataframe is correct size", {
+  expect_that(dim(sim.results)[1], equals(nrow(cases)))
+  expect_that(dim(sim.results)[2], equals(3 + ncol(cases)))
+  expect_that(sim.results, is_a("data.frame"))
+})
+
+test_that("values of simulations are sensible", {  
+  expect_that(all(sim.results$yhatMin < sim.results$yhats), is_true())
+  expect_that(all(sim.results$yhatMax > sim.results$yhats), is_true())
+  expect_that(all(!is.na(sim.results$yhats)), is_true())
+  expect_that(all(!is.na(sim.results$yhatMin)), is_true())
+  expect_that(all(!is.na(sim.results$yhatMax)), is_true())
+})
